const express = require('express');
const bcrypt = require('bcrypt');
const db = require('./db');

const router = express.Router();


router.post('/Register', async (req, res) => {
    try {
        const { username, password } = req.body;


        const hashedPassword = await bcrypt.hash(password, 10);

        const result = await db.query(
            'INSERT INTO user_accounts (username, password) VALUES ($1, $2) RETURNING id',
            [username, hashedPassword]
        );

        const userId = result.rows[0].id;

        return res.status(201).json({ userId });
    } catch (error) {
        if (error.constraint === 'user_accounts_username_key') {
            return res.status(409).json({ error: 'Username already exists' });
        } else {
            console.error('Error during registration:', error);
            res.status(500).json({ error: 'Server error' });
        }
    }
});


router.post('/Login', async (req, res) => {
    try {
        const { username, password } = req.body;

        const result = await db.query('SELECT * FROM user_accounts WHERE username = $1', [username]);

        if (result.rows.length === 0) {
            return res.status(400).json({ error: 'User account not found' });
        }

        const user = result.rows[0];
        const isPasswordMatch = await bcrypt.compare(password, user.password);

        if (isPasswordMatch) {
            // Generate JWT or session here and send a success response
            return res.status(200).json({ message: 'Login successful', userId: user.id });
        } else {
            return res.status(401).json({ error: 'Invalid credentials' });
        }
    } catch (error) {
        console.error('Error during login:', error);
        res.status(500).json({ error: 'Server error' });
    }
});


router.get('/Account/:userId', async (req, res) => {
    try {
        const userId = req.params.userId;

        const result = await db.query('SELECT * FROM user_account_details WHERE user_id = $1', [userId]);

        if (result.rows.length === 0) {
            return res.status(204).json({ message: 'No account data found' });
        }

        const accountData = result.rows[0];
        return res.status(200).json(accountData);
    } catch (error) {
        console.error('Error fetching account data:', error);
        res.status(500).json({ error: 'Server error' });
    }
});


router.put('/Account', async (req, res) => {
    try {
        const userId = req.params.userId;
        const { firstname, lastname, address1, address2, state, zipcode, phone, email } = req.body;

        const result = await db.query(
            'UPDATE user_account_details SET firstname = $1, lastname = $2, address1 = $3, address2 = $4, state = $5, zipcode = $6, phone = $7, email = $8 WHERE user_id = $9',
            [firstname, lastname, address1, address2, state, zipcode, phone, email, userId]
        );

        if (result.rowCount === 0) {
            return res.status(404).json({ error: 'Account data not found' });
        }

        return res.status(200).json({ message: 'Account data updated successfully' });
    } catch (error) {
        console.error('Error updating account data:', error);
        res.status(500).json({ error: 'Server error' });
    }
});

module.exports = router;
